import { Switch, Route, useLocation } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import { UpsellProvider } from "@/lib/upsell-context";
import ABTestProvider from "@/lib/ab-testing";
import { AuthProvider } from "@/hooks/use-auth";
import { useEffect } from "react";
import { trackPageView, trackEmailClick } from "@/lib/analytics";
import NotFound from "@/pages/not-found";
import Home from "@/pages/home";
import Checkout from "@/pages/checkout";
import Success from "@/pages/success";
import Booking from "./pages/booking";
import Upsell from "@/pages/upsell";
import TestFlow from "@/pages/test-flow";
import TestUpload from "@/pages/test-upload";
import AdminLogin from "@/pages/admin-login";
import AdminAnalytics from "@/pages/admin-analytics";
import AdminABTests from "@/pages/admin-ab-tests";
import AdminMauticStyled from "@/pages/admin-mautic-styled";
import AdminFunnel from "@/pages/admin-funnel";
import CampaignEmailsPage from "@/pages/campaign-emails";
import AdminZoom from "@/pages/admin-zoom";
import AdminSettings from "@/pages/admin-settings";
import FacebookAdsPage from "@/pages/facebook-ads";
import FacebookAdsUpload from "@/pages/facebook-ads-upload";
import AdminKPIDashboard from "@/pages/admin-kpi-dashboard";
import ProtectedAdminRoute from "@/components/protected-admin-route";
import AdminRedirect from "@/components/admin-redirect";
import { TestModeIndicator } from "@/components/test-mode-indicator";
import PageTransition from "@/components/page-transition";

function AppRoutes() {
  const [location] = useLocation();
  
  // Track page views and email clicks on route change
  useEffect(() => {
    // Always track page view
    trackPageView(location);
    
    // Check for email tracking parameters in URL
    const searchParams = new URLSearchParams(window.location.search);
    if (searchParams.has('from') && searchParams.get('from') === 'email') {
      // Track as an email click if the "from=email" parameter is present
      if (searchParams.has('campaign') || searchParams.has('email')) {
        trackEmailClick(location);
      }
    }
  }, [location]);

  return (
    <PageTransition>
      <Switch>
        <Route path="/" component={Home} />
        <Route path="/checkout" component={Checkout} />
        <Route path="/success" component={Success} />
        <Route path="/booking" component={Booking} />
        <Route path="/upsell" component={Upsell} />
        <Route path="/book-call" component={Booking} />
        <Route path="/admin/login" component={AdminLogin} />
        <ProtectedAdminRoute path="/admin/analytics" component={AdminAnalytics} />
        <ProtectedAdminRoute path="/admin/funnel" component={AdminFunnel} />
        <ProtectedAdminRoute path="/admin/ab-tests" component={AdminABTests} />
        <ProtectedAdminRoute path="/admin/mautic" component={AdminMauticStyled} />
        <ProtectedAdminRoute path="/admin/mautic/campaign/:id" component={CampaignEmailsPage} />
        <ProtectedAdminRoute path="/admin/mautic/campaigns/:id" component={CampaignEmailsPage} />
        <ProtectedAdminRoute path="/admin/zoom" component={AdminZoom} />
        <ProtectedAdminRoute path="/admin/facebook-ads" component={FacebookAdsPage} />
        <ProtectedAdminRoute path="/admin/facebook-ads-upload" component={FacebookAdsUpload} />
        <ProtectedAdminRoute path="/admin/kpi-dashboard" component={AdminKPIDashboard} />
        <ProtectedAdminRoute path="/admin/settings" component={AdminSettings} />
        <Route path="/admin" component={AdminRedirect} />
        <Route path="/test-flow" component={TestFlow} />
        <Route path="/test-upload" component={TestUpload} />
        <Route component={NotFound} />
      </Switch>
    </PageTransition>
  );
}

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <AuthProvider>
        <UpsellProvider>
          <ABTestProvider>
            <div style={{ position: 'relative', width: '100%', minHeight: '100vh' }}>
              <AppRoutes />
              <TestModeIndicator />
              <Toaster />
            </div>
          </ABTestProvider>
        </UpsellProvider>
      </AuthProvider>
    </QueryClientProvider>
  );
}

export default App;
